@@ -19,14 +19,16 @@
 
 #include "staff-grouper-interface.hh"
 
+#include "hara-kiri-group-spanner.hh"
 #include "pointer-group-interface.hh"
 
 Grob*
-Staff_grouper_interface::get_last_grob (Grob *me)
+Staff_grouper_interface::get_maybe_pure_last_grob (Grob *me, bool pure, int start, int end)
 {
   extract_grob_set (me, "elements", elts);
   for (vsize i = elts.size (); i--;)
-    if (elts[i]->is_live ())
+    if ((pure && !Hara_kiri_group_spanner::request_suicide (me, start, end))
+	|| (!pure && elts[i]->is_live ()))
       return elts[i];
 
   return 0;
